# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.3.0-v202405011708
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AgentOrchestratorOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_provisioning_expiration_at': 'str',
        'agent_provisioning_requested_at': 'str',
        'agent_provisioning_status': 'str',
        'name': 'str'
    }

    attribute_map = {
        'agent_provisioning_expiration_at': 'agentProvisioningExpirationAt',
        'agent_provisioning_requested_at': 'agentProvisioningRequestedAt',
        'agent_provisioning_status': 'agentProvisioningStatus',
        'name': 'name'
    }

    def __init__(self, agent_provisioning_expiration_at=None, agent_provisioning_requested_at=None, agent_provisioning_status=None, name=None):
        """
        AgentOrchestratorOutputV1 - a model defined in Swagger
        """

        self._agent_provisioning_expiration_at = None
        self._agent_provisioning_requested_at = None
        self._agent_provisioning_status = None
        self._name = None

        if agent_provisioning_expiration_at is not None:
          self.agent_provisioning_expiration_at = agent_provisioning_expiration_at
        if agent_provisioning_requested_at is not None:
          self.agent_provisioning_requested_at = agent_provisioning_requested_at
        if agent_provisioning_status is not None:
          self.agent_provisioning_status = agent_provisioning_status
        if name is not None:
          self.name = name

    @property
    def agent_provisioning_expiration_at(self):
        """
        Gets the agent_provisioning_expiration_at of this AgentOrchestratorOutputV1.
        The ISO 8601 date when agent provisioning will expire (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The agent_provisioning_expiration_at of this AgentOrchestratorOutputV1.
        :rtype: str
        """
        return self._agent_provisioning_expiration_at

    @agent_provisioning_expiration_at.setter
    def agent_provisioning_expiration_at(self, agent_provisioning_expiration_at):
        """
        Sets the agent_provisioning_expiration_at of this AgentOrchestratorOutputV1.
        The ISO 8601 date when agent provisioning will expire (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param agent_provisioning_expiration_at: The agent_provisioning_expiration_at of this AgentOrchestratorOutputV1.
        :type: str
        """

        self._agent_provisioning_expiration_at = agent_provisioning_expiration_at

    @property
    def agent_provisioning_requested_at(self):
        """
        Gets the agent_provisioning_requested_at of this AgentOrchestratorOutputV1.
        The ISO 8601 date when agent provisioning was requested (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The agent_provisioning_requested_at of this AgentOrchestratorOutputV1.
        :rtype: str
        """
        return self._agent_provisioning_requested_at

    @agent_provisioning_requested_at.setter
    def agent_provisioning_requested_at(self, agent_provisioning_requested_at):
        """
        Sets the agent_provisioning_requested_at of this AgentOrchestratorOutputV1.
        The ISO 8601 date when agent provisioning was requested (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param agent_provisioning_requested_at: The agent_provisioning_requested_at of this AgentOrchestratorOutputV1.
        :type: str
        """

        self._agent_provisioning_requested_at = agent_provisioning_requested_at

    @property
    def agent_provisioning_status(self):
        """
        Gets the agent_provisioning_status of this AgentOrchestratorOutputV1.
        The provisioning status of the agent

        :return: The agent_provisioning_status of this AgentOrchestratorOutputV1.
        :rtype: str
        """
        return self._agent_provisioning_status

    @agent_provisioning_status.setter
    def agent_provisioning_status(self, agent_provisioning_status):
        """
        Sets the agent_provisioning_status of this AgentOrchestratorOutputV1.
        The provisioning status of the agent

        :param agent_provisioning_status: The agent_provisioning_status of this AgentOrchestratorOutputV1.
        :type: str
        """
        allowed_values = ["PRE_PROVISIONED", "PROVISIONED"]
        if agent_provisioning_status not in allowed_values:
            raise ValueError(
                "Invalid value for `agent_provisioning_status` ({0}), must be one of {1}"
                .format(agent_provisioning_status, allowed_values)
            )

        self._agent_provisioning_status = agent_provisioning_status

    @property
    def name(self):
        """
        Gets the name of this AgentOrchestratorOutputV1.
        The name of the agent orchestrator. This name uniquely identifies the agent orchestrator

        :return: The name of this AgentOrchestratorOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AgentOrchestratorOutputV1.
        The name of the agent orchestrator. This name uniquely identifies the agent orchestrator

        :param name: The name of this AgentOrchestratorOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AgentOrchestratorOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.3.0-v202405011708
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class AssistantStatusV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'available': 'bool',
        'enabled': 'bool',
        'message': 'str'
    }

    attribute_map = {
        'available': 'available',
        'enabled': 'enabled',
        'message': 'message'
    }

    def __init__(self, available=None, enabled=None, message=None):
        """
        AssistantStatusV1 - a model defined in Swagger
        """

        self._available = None
        self._enabled = None
        self._message = None

        if available is not None:
          self.available = available
        if enabled is not None:
          self.enabled = enabled
        if message is not None:
          self.message = message

    @property
    def available(self):
        """
        Gets the available of this AssistantStatusV1.
        True if the assistant service is up and running and available to take requests.

        :return: The available of this AssistantStatusV1.
        :rtype: bool
        """
        return self._available

    @available.setter
    def available(self, available):
        """
        Sets the available of this AssistantStatusV1.
        True if the assistant service is up and running and available to take requests.

        :param available: The available of this AssistantStatusV1.
        :type: bool
        """

        self._available = available

    @property
    def enabled(self):
        """
        Gets the enabled of this AssistantStatusV1.
        True if the assistant is enabled and the access key is valid.

        :return: The enabled of this AssistantStatusV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this AssistantStatusV1.
        True if the assistant is enabled and the access key is valid.

        :param enabled: The enabled of this AssistantStatusV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def message(self):
        """
        Gets the message of this AssistantStatusV1.
        A human-readable system message than includes error details if the assistant is not enabled and/or available.

        :return: The message of this AssistantStatusV1.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this AssistantStatusV1.
        A human-readable system message than includes error details if the assistant is not enabled and/or available.

        :param message: The message of this AssistantStatusV1.
        :type: str
        """

        self._message = message

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AssistantStatusV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
